opnsense-ports/www/swish++/files/patch-xml_formatter.c
Franco Fichtner 8cb1a96ede ports: pull in a snapshot of the FreeBSD ports tree
Taken from:	https://github.com/freebsd/freebsd-ports.git
Commit id:	5070672073b68be364139bc6b3a89100bd17d331
2014-11-09 14:03:21 +01:00

28 lines
733 B
C

--- xml_formatter.c.orig
+++ xml_formatter.c
@@ -144,7 +144,7 @@
//
// SYNOPSIS
//
- void xml_formatter::result( int rank, file_info const &fi ) const
+ void xml_formatter::result( int my_rank, file_info const &fi ) const
//
// DESCRIPTION
//
@@ -153,14 +153,14 @@
//
// PARAMETERS
//
// rank The rank (1-100) of the result.
//
// fi The search result's file information.
//
//*****************************************************************************
{
out_ << " <File>\n"
- " <Rank>" << rank << "</Rank>\n"
+ " <Rank>" << my_rank << "</Rank>\n"
" <Path>"
<< directories[ fi.dir_index() ] << '/' << fi.file_name()
<< "</Path>\n"
@@ -153,14 +153,14 @@
// PARAMETERS
//
-// rank The rank (1-100) of the result.
+// my_rank The rank (1-100) of the result.
//
// fi The search result's file information.